@@ -36,10 +36,10 @@ class VersionProps {
         "openjdk";
 
     private static final String java_version =
-        "11.0.22";
+        "11.0.24";
 
     private static final String java_version_date =
-        "2024-01-16";
+        "2024-07-16";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -47,13 +47,13 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "11.0.22+7";
+        "11.0.24+8";
 
     private static final String VERSION_NUMBER =
-        "11.0.22";
+        "11.0.24";
 
     private static final String VERSION_BUILD =
-        "7";
+        "8";
 
     private static final String VERSION_PRE =
         "";
@@ -65,7 +65,7 @@ class VersionProps {
         "".startsWith("LTS");
 
     private static final String VENDOR =
-        "Oracle Corporation";
+        "Arch Linux";
 
     private static final String VENDOR_URL =
         "https://openjdk.java.net/";
